.onLoad <- function(libname, pkgname) {
  require_lamindb(silent = TRUE)
}
